clear all
clc
addpath('utils');

dataset_path = 'datasets/AwA';
load(sprintf('%s/predicateMatrixContinuous.mat', dataset_path));
load(sprintf('%s/feat-imagenet-vgg-verydeep-19.mat', dataset_path));
load(sprintf('%s/trainTestSplit.mat', dataset_path));

class_attributes = predicateMatrixContinuous/max(max(predicateMatrixContinuous));
train_feature=double(train_feat);
test_feature=double(test_feat);

train_label=double(class_attributes(train_labels,:))';
test_label=double(class_attributes(test_labels,:))';

test_class_label=double(class_attributes(testClassLabels,:))';
train_class_label=double(class_attributes(trainClassLabels,:))';

%% parameter settings
pars.alpha=30;
pars.beta=20;
pars.gamma = 1;
pars.iter=150;
pars.numBaseU=200;
pars.dimFeature=size(train_feature,1);
pars.dimSemantic = size(class_attributes,2);
pars.numTrainClass = length(trainClassLabels);

name = 'datasets/initial_awa_ADS.mat';
if ~exist(name,'file')
    [D,W,U]= initial(pars,name);
else
    load(name);
end

SIM = get_sim(class_attributes, trainClassLabels);
H = get_H(trainClassLabels, train_labels );

X0=learn_coefficients_noise(D,train_feature,pars.gamma);
W=learn_basis(X0,train_label,pars.gamma);
U=learn_basis(H,X0,pars.gamma);

%% train models
fprintf('Optimizing the models...\n');
[D, W, U] = optimize(train_feature,train_label,H,D,W,U,pars);
fprintf('Testing the models...\n');
accuracy = evaluate(test_feature,test_labels,testClassLabels,test_class_label,SIM,D,W,U,pars);
fprintf('test accuracy is %.2f%%',accuracy*100);

